@@ -100,36 +100,36 @@
      "------------------ XEmacs XMine ------------------")))
 
 (defvar xmine-glyph-production-list
-  '(("xmine-new-up"            "new_up.gif"               "new"  nil)
-    ("xmine-new-down"          "new_down.gif"             "NEW"  nil)
-    ("xmine-quit-up"           "quit_up.gif"              "quit" nil)
-    ("xmine-quit-down"         "quit_down.gif"   	  "QUIT" nil)
-    ("xmine-up-glyph"          "empty_16_up.gif"          "@ "   xmine-hidden-face)
-    ("xmine-up-sel-glyph"      "empty_16_up_sel.gif"      "@<"   xmine-hidden-face)
-    ("xmine-down-glyph"        "empty_16_down.gif"        "? "   nil) 
-    ("xmine-flagged-glyph"     "flagged_16_up.gif"        "! "   xmine-flagged-face)
-    ("xmine-flagged-sel-glyph" "flagged_16_up_sel.gif"    "!<"   xmine-flagged-face)
-    ("xmine-mine-glyph"        "bomb_16_flat.gif"         "* "   nil)
-    ("xmine-mine-sel-glyph"    "bomb_16_flat.gif"         "*<"   nil)
-    ("xmine-trapped-glyph"     "bomb_trapped_16_flat.gif" "X "   nil)
-    ("xmine-0-glyph"           "empty_16_flat.gif"        ". "   nil)
-    ("xmine-0-sel-glyph"       "empty_16_flat_sel.gif"    ".<"   nil)
-    ("xmine-1-glyph"           "1_16_flat.gif"            "1 "   xmine-number-face)
-    ("xmine-1-sel-glyph"       "1_16_flat_sel.gif"        "1<"   xmine-number-face)
-    ("xmine-2-glyph"           "2_16_flat.gif"            "2 "   xmine-number-face)
-    ("xmine-2-sel-glyph"       "2_16_flat_sel.gif"        "2<"   xmine-number-face)
-    ("xmine-3-glyph"           "3_16_flat.gif"            "3 "   xmine-number-face)
-    ("xmine-3-sel-glyph"       "3_16_flat_sel.gif"        "3<"   xmine-number-face)
-    ("xmine-4-glyph"           "4_16_flat.gif"            "4 "   xmine-number-face)
-    ("xmine-4-sel-glyph"       "4_16_flat_sel.gif"        "4<"   xmine-number-face)
-    ("xmine-5-glyph"           "5_16_flat.gif"            "5 "   xmine-number-face)
-    ("xmine-5-sel-glyph"       "5_16_flat_sel.gif"        "5<"   xmine-number-face)
-    ("xmine-6-glyph"           "6_16_flat.gif"            "6 "   xmine-number-face)
-    ("xmine-6-sel-glyph"       "6_16_flat_sel.gif"        "6<"   xmine-number-face)
-    ("xmine-7-glyph"           "7_16_flat.gif"            "7 "   xmine-number-face)
-    ("xmine-7-sel-glyph"       "7_16_flat_sel.gif"        "7<"   xmine-number-face)
-    ("xmine-8-glyph"           "8_16_flat.gif"            "8 "   xmine-number-face)
-    ("xmine-8-sel-glyph"       "8_16_flat_sel.gif"        "8<"   xmine-number-face)))
+  '(("xmine-new-up"            "new_up.png"               "new"  nil)
+    ("xmine-new-down"          "new_down.png"             "NEW"  nil)
+    ("xmine-quit-up"           "quit_up.png"              "quit" nil)
+    ("xmine-quit-down"         "quit_down.png"   	  "QUIT" nil)
+    ("xmine-up-glyph"          "empty_16_up.png"          "@ "   xmine-hidden-face)
+    ("xmine-up-sel-glyph"      "empty_16_up_sel.png"      "@<"   xmine-hidden-face)
+    ("xmine-down-glyph"        "empty_16_down.png"        "? "   nil) 
+    ("xmine-flagged-glyph"     "flagged_16_up.png"        "! "   xmine-flagged-face)
+    ("xmine-flagged-sel-glyph" "flagged_16_up_sel.png"    "!<"   xmine-flagged-face)
+    ("xmine-mine-glyph"        "bomb_16_flat.png"         "* "   nil)
+    ("xmine-mine-sel-glyph"    "bomb_16_flat.png"         "*<"   nil)
+    ("xmine-trapped-glyph"     "bomb_trapped_16_flat.png" "X "   nil)
+    ("xmine-0-glyph"           "empty_16_flat.png"        ". "   nil)
+    ("xmine-0-sel-glyph"       "empty_16_flat_sel.png"    ".<"   nil)
+    ("xmine-1-glyph"           "1_16_flat.png"            "1 "   xmine-number-face)
+    ("xmine-1-sel-glyph"       "1_16_flat_sel.png"        "1<"   xmine-number-face)
+    ("xmine-2-glyph"           "2_16_flat.png"            "2 "   xmine-number-face)
+    ("xmine-2-sel-glyph"       "2_16_flat_sel.png"        "2<"   xmine-number-face)
+    ("xmine-3-glyph"           "3_16_flat.png"            "3 "   xmine-number-face)
+    ("xmine-3-sel-glyph"       "3_16_flat_sel.png"        "3<"   xmine-number-face)
+    ("xmine-4-glyph"           "4_16_flat.png"            "4 "   xmine-number-face)
+    ("xmine-4-sel-glyph"       "4_16_flat_sel.png"        "4<"   xmine-number-face)
+    ("xmine-5-glyph"           "5_16_flat.png"            "5 "   xmine-number-face)
+    ("xmine-5-sel-glyph"       "5_16_flat_sel.png"        "5<"   xmine-number-face)
+    ("xmine-6-glyph"           "6_16_flat.png"            "6 "   xmine-number-face)
+    ("xmine-6-sel-glyph"       "6_16_flat_sel.png"        "6<"   xmine-number-face)
+    ("xmine-7-glyph"           "7_16_flat.png"            "7 "   xmine-number-face)
+    ("xmine-7-sel-glyph"       "7_16_flat_sel.png"        "7<"   xmine-number-face)
+    ("xmine-8-glyph"           "8_16_flat.png"            "8 "   xmine-number-face)
+    ("xmine-8-sel-glyph"       "8_16_flat_sel.png"        "8<"   xmine-number-face)))
 
 (defvar xmine-force-textual nil
   "This is for debugging purposes only. No need to set it. Really.")
